#!/usr/bin/env ruby
# frozen_string_literal

require 'bundler/inline'

gemfile do
  source 'https://rubygems.org'

  gem 'oj'
  gem 'benchmark-ips', require: 'benchmark/ips'
end

require 'json'
require 'open-uri'

CANADA_DATA_JSON = URI.parse('https://raw.githubusercontent.com/serde-rs/json-benchmark/master/data/canada.json').read
CANADA_DATA = JSON.parse(CANADA_DATA_JSON)

Benchmark.ips do |x|
  x.config(:time => 10, :warmup => 5)

  x.report("marshall Canada data with Oj") do
    Oj.dump(CANADA_DATA)
  end

  x.report("marshall Canada data with JSON") do
    JSON.dump(CANADA_DATA)
  end

  x.compare!
end

Oj.default_options = {
  mode: :strict,
  bigdecimal_load: :fast
}

Benchmark.ips do |x|
  x.config(:time => 10, :warmup => 5)

  x.report("unmarshall Canada data with Oj") do
    Oj.load(CANADA_DATA_JSON)
  end

  x.report("unmarshall Canada data with JSON") do
    JSON.parse(CANADA_DATA_JSON)
  end

  x.compare!
end
